---
title: ?Substance?
subtitle: This is an interactive analysis of ?substance? pharmacokinetics
layout: page
hero_height: 80px

---



# PK-DB Team
PK-DB is developed from the Systems Medicine of the Liver Group of Matthias König at the Humboldt-University Berlin.


# Licensing
All data is governed by the PK-DB's Terms of use

# How to cite
PK-DB: PharmacoKinetics DataBase for Individualized and Stratified Computational Modeling
Jan Grzegorzewski, Janosch Brandhorst, Dimitra Eleftheriadou, Kathleen Green, Matthias König
bioRxiv 760884; doi: https://doi.org/10.1101/760884

